@@ -763,7 +763,7 @@ class MainView(QMainWindow, Observable):
         self.set_menus()
         self.setWindowTitle('Simple Slice Viewer')
         
-        icon = qta.icon('fa5s.pizza-slice')
+        icon = qta.icon('fa5s.pizza-slice', color='#ff4000')
         self.setWindowIcon(icon)
     
 
